==> RailgunS-0.21.tar.gz: RailgunS-0.21/README.md <==
# RailgunS

[![Downloads](https://pepy.tech/badge/railguns)](https://pepy.tech/project/railguns)
[![PyPI](https://img.shields.io/pypi/v/railguns)](https://pypi.org/project/RailgunS/)
[![Python](https://img.shields.io/pypi/pyversions/railguns)](https://www.python.org)
[![Django](https://img.shields.io/pypi/djversions/railguns)](https://www.djangoproject.com)
[![License](https://img.shields.io/pypi/l/railguns)](https://opensource.org/licenses/MIT)

Only My Railgun

---

## Installation

```bash
sudo pip install railguns
```

## Vendor

框架用到的库

- [Django](https://www.djangoproject.com)
- [Django REST framework](https://www.django-rest-framework.org)
- [Simple JWT](https://github.com/davesque/django-rest-framework-simplejwt)

部署

- [Gunicorn](https://www.gunicorn.org)
- [uvicorn](https://www.uvicorn.org)

常用库

- [Django CKEditor](https://github.com/django-ckeditor/django-ckeditor)
- [Django Filter](https://django-filter.readthedocs.io)
- [django-htmlmin](https://github.com/cobrateam/django-htmlmin)
- [django-redis-cache](https://django-redis-cache.readthedocs.io)
- [hiredis](https://github.com/redis/hiredis)
- [mysqlclient](https://github.com/PyMySQL/mysqlclient-python)

开发调试库

- [Django Debug Toolbar](https://django-debug-toolbar.readthedocs.io)
- [django-debug-toolbar-force](https://django-debug-toolbar-force.readthedocs.io)
- [Rosetta](https://django-rosetta.readthedocs.io)

前端库

- [axios](https://github.com/axios/axios)
- [jQuery](https://jquery.com)
- [jQuery Lazy](http://jquery.eisbehr.de/lazy/)
- [Material Components for the Web](https://material.io/components/web/)
- [Vue.js](https://vuejs.org)
- [WeUI](https://github.com/Tencent/weui)
- [weui.js](https://github.com/Tencent/weui.js)

前端可选库

- [clipboard.js](https://clipboardjs.com)
- [GeoPattern](https://btmills.github.io/geopattern/)
- [localForage](https://localforage.github.io/localForage/)
- [Lodash](https://lodash.com)
- [Moment](https://momentjs.com)
- [Numeral.js](https://numeraljs.com/)

## License

RailgunS is released under the MIT license. [See LICENSE](https://github.com/nyssance/railguns/blob/master/LICENSE) for details.

==> RailgunS-0.39.tar.gz: RailgunS-0.39/README.md <==
# RailgunS

[![Downloads](https://pepy.tech/badge/railguns)](https://pepy.tech/project/railguns)
[![PyPI](https://img.shields.io/pypi/v/railguns)](https://pypi.org/project/RailgunS/)
[![Python](https://img.shields.io/pypi/pyversions/railguns)](https://www.python.org)
[![Django](https://img.shields.io/pypi/djversions/railguns)](https://www.djangoproject.com)
[![License](https://img.shields.io/pypi/l/railguns)](https://opensource.org/licenses/MIT)

Only My Railgun

---

## Installation

```sh
pip install railguns
```

## Vendor

框架用到的库

- [Django](https://www.djangoproject.com)
- [Django REST framework](https://www.django-rest-framework.org)
- [Simple JWT](https://github.com/davesque/django-rest-framework-simplejwt)

部署

- [Gunicorn](https://www.gunicorn.org)
- [uvicorn](https://www.uvicorn.org)

常用库

- [Django CKEditor](https://github.com/django-ckeditor/django-ckeditor)
- [Django Filter](https://django-filter.readthedocs.io)
- [django-htmlmin](https://github.com/cobrateam/django-htmlmin)
- [django-redis-cache](https://django-redis-cache.readthedocs.io)
- [hiredis](https://github.com/redis/hiredis)
- [mysqlclient](https://github.com/PyMySQL/mysqlclient-python)

前端库

- [axios](https://github.com/axios/axios)
- [jQuery](https://jquery.com)
- [jQuery Lazy](http://jquery.eisbehr.de/lazy/)
- [Material Components for the Web](https://material.io/components/web/)
- [Vue.js](https://vuejs.org)
- [WeUI](https://github.com/Tencent/weui)
- [weui.js](https://github.com/Tencent/weui.js)

## License

RailgunS is released under the MIT license. [See LICENSE](https://github.com/nyssance/railguns/blob/master/LICENSE) for details.
